# PermitSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**permit_reference_number** | **str** |  | 
**proposed_start_date** | **datetime** |  | 
**proposed_end_date** | **datetime** |  | 
**actual_start_date** | **datetime** |  | [optional] 
**actual_stop_date** | **datetime** |  | [optional] 
**permit_status** | [**PermitStatusResponse**](PermitStatusResponse.md) |  | 
**permit_status_string** | **str** |  | 
**work_category** | [**WorkCategoryResponseEnum**](WorkCategoryResponseEnum.md) |  | 
**work_category_string** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

